==> acs_0.25.orig.tar.gz: acs-0.25/src/s_dc_swp.cc <==
/*$Id: s_dc_swp.cc,v 15.7 1999/10/06 05:29:38 al Exp $ -*- C++ -*-
 * dc analysis sweep
 */
#include "l_denoise.h"
#include "l_compar.h"
#include "e_card.h"
#include "constant.h"
#include "s_dc.h"
/*--------------------------------------------------------------------------*/
//	void	DCOP::sweep(void);
//	void	DCOP::first(int);
//	bool	DCOP::next(int);
/*--------------------------------------------------------------------------*/
void DCOP::sweep(void)
{
  int converged;
  int itl = OPT::itl[OPT::DCBIAS];
  
  head(start[0], stop[0], linswp[0], " ");
  bypass_ok = false;
  inc_mode = tsBAD;
  if (cont){
    untested();
    restore();
  }
  
  first(0);
  CARD_LIST::card_list.dc_begin();
  do {
    IO::suppresserrors = trace < tVERBOSE;
    converged = solve(itl,trace);
    if (!converged){
      untested();
      error(bWARNING, "did not converge\n");
    }
    STATUS::accept.start();
    CARD_LIST::card_list.tr_accept();
    STATUS::accept.stop();
    keep();
    outdata(*sweepval[0]);
    itl = OPT::itl[OPT::DCXFER];
  } while (next(0));
}
/*--------------------------------------------------------------------------*/
void DCOP::first(int ii)
{
  *sweepval[ii] = start[ii];
  if (exists(zap[ii])){
    zap[ii]->expand();
    zap[ii]->precalc();
  }
  
  if (reverse){
    untested();
    reverse = false;
    while (next(ii))
      /* nothing */;
    reverse = true;
    next(ii);
  }
  STATUS::control[cSTEPCAUSE] = scUSER;
  phase = pINIT_DC;
}
/*--------------------------------------------------------------------------*/
bool DCOP::next(int ii)
{
  bool ok = false;
  {if (linswp[ii]){
    double fudge = step[ii] / 10.;
    {if (step[ii] == 0.){
      ok = false;
    }else{
      if (!reverse){
	//*(sweepval[ii]) += step[ii];
	*(sweepval[ii]) = dn_sum(*(sweepval[ii]), step[ii]);
	ok=inorder(start[ii]-fudge,*(sweepval[ii]),stop[ii]+fudge);
	if (!ok  &&  loop){
	  reverse = true;
	}
      }
      if (reverse){
	//*(sweepval[ii]) -= step[ii];
	*(sweepval[ii]) = dn_diff(*(sweepval[ii]), step[ii]);
	ok=inorder(start[ii]-fudge,*(sweepval[ii]),stop[ii]+fudge);
      }
    }}
  }else{
    double fudge = pow(step[ii], .1);
    {if (step[ii] == 1.){
      untested();
      ok = false;
    }else{
      {if (!reverse){
	*(sweepval[ii]) *= step[ii];
	ok=inorder(start[ii]/fudge,*(sweepval[ii]),stop[ii]*fudge);
	if (!ok  &&  loop){
	  untested();
	  reverse = true;
	}     
      }else{
	untested();
      }}
      if (reverse){
	untested();
	*(sweepval[ii]) /= step[ii];
	ok=inorder(start[ii]/fudge,*(sweepval[ii]),stop[ii]*fudge);
      }
    }}
  }}
  if (exists(zap[ii])){
    zap[ii]->expand();
    zap[ii]->precalc();
  }
  STATUS::control[cSTEPCAUSE] = scUSER;
  phase = pDC_SWEEP;
  return ok;
}
/*--------------------------------------------------------------------------*/
/*--------------------------------------------------------------------------*/

==> acs-0.28.tar.gz: acs-0.28/src/s_dc_swp.cc <==
/*$Id: s_dc_swp.cc,v 18.17 2000/09/04 09:45:33 al Exp $ -*- C++ -*-
 * dc analysis sweep
 */
#include "l_denoise.h"
#include "l_compar.h"
#include "e_card.h"
#include "constant.h"
#include "s_dc.h"
/*--------------------------------------------------------------------------*/
//	void	DCOP::sweep(void);
//	void	DCOP::first(int);
//	bool	DCOP::next(int);
/*--------------------------------------------------------------------------*/
void DCOP::sweep(void)
{
  int converged;
  int itl = OPT::itl[OPT::DCBIAS];
  
  head(start[0], stop[0], linswp[0], " ");
  bypass_ok = false;
  inc_mode = tsBAD;
  if (cont) {
    untested();
    restore();
  }
  
  first(0);
  clear_limit();
  CARD_LIST::card_list.dc_begin();
  do {
    IO::suppresserrors = trace < tVERBOSE;
    converged = solve(itl,trace);
    if (!converged) {
      untested();
      error(bWARNING, "did not converge\n");
    }
    STATUS::accept.start();
    set_limit();
    CARD_LIST::card_list.tr_accept();
    STATUS::accept.stop();
    keep();
    outdata(*sweepval[0]);
    itl = OPT::itl[OPT::DCXFER];
  } while (next(0));
}
/*--------------------------------------------------------------------------*/
void DCOP::first(int ii)
{
  *sweepval[ii] = start[ii];
  if (reverse) {
    untested();
    reverse = false;
    while (next(ii))
      /* nothing */;
    reverse = true;
    next(ii);
  }
  phase = pINIT_DC;
}
/*--------------------------------------------------------------------------*/
bool DCOP::next(int ii)
{
  bool ok = false;
  {if (linswp[ii]) {
    double fudge = step[ii] / 10.;
    {if (step[ii] == 0.) {
      ok = false;
    }else{
      if (!reverse) {
	*(sweepval[ii]) += step[ii];
	fixzero(sweepval[ii], step[ii]);
	ok=inorder(start[ii]-fudge,*(sweepval[ii]),stop[ii]+fudge);
	if (!ok  &&  loop) {
	  reverse = true;
	}
      }
      if (reverse) {
	*(sweepval[ii]) -= step[ii];
	fixzero(sweepval[ii], step[ii]);
	ok=inorder(start[ii]-fudge,*(sweepval[ii]),stop[ii]+fudge);
      }
    }}
  }else{
    double fudge = pow(step[ii], .1);
    {if (step[ii] == 1.) {
      untested();
      ok = false;
    }else{
      {if (!reverse) {
	*(sweepval[ii]) *= step[ii];
	ok=inorder(start[ii]/fudge,*(sweepval[ii]),stop[ii]*fudge);
	if (!ok  &&  loop) {
	  untested();
	  reverse = true;
	}     
      }else{
	untested();
      }}
      if (reverse) {
	untested();
	*(sweepval[ii]) /= step[ii];
	ok=inorder(start[ii]/fudge,*(sweepval[ii]),stop[ii]*fudge);
      }
    }}
  }}
  phase = pDC_SWEEP;
  return ok;
}
/*--------------------------------------------------------------------------*/
/*--------------------------------------------------------------------------*/
